@@ -1,3 +1,6 @@
+import json
+import ast
+
 import click
 import os, shutil
 import re
@@ -27,6 +30,7 @@ directories = {
     'test_schema': '',
     'trainer': '',
     'server': '',
+    'dsp': '',
 }
 
 
@@ -38,8 +42,8 @@ class AliasedGroup(click.Group):
             pass
         return super().get_command(ctx, cmd_name)
 
-
 @click.group(cls=AliasedGroup)
+@click.version_option(package_name='dsFramework')
 def cli():
     """
     DS framework cli
@@ -111,6 +115,50 @@ def run_server():
     folder = currentPipelineFolder + '/server/main.py'
     subprocess.call('python ' + folder, shell=True)
 
+@cli.command()
+@click.argument('tag')
+@click.argument('env', default="prd")
+def cloud_eval(tag, env):
+    currentPipelineFolder = os.path.abspath(os.getcwd())
+    currentParentFolder = os.path.join(currentPipelineFolder,"..")
+    os.environ["PYTHONPATH"] = currentPipelineFolder
+    folder = currentPipelineFolder + '/tester/dsp/get_model_options.py'
+    output = subprocess.check_output('python ' + folder + ' ' + env, shell=True, encoding='utf-8').strip()
+    if output:
+        # print('output', output)
+        l = output.split('\n')
+        m = l[-1]
+        try:
+            l = ast.literal_eval(m)
+            o = l[0]
+            model = {
+                'name': o['name'],
+                'id': o['id'],
+                'repo': o['repo'],
+            }
+            folder = currentPipelineFolder + '/tester/dsp/get_dataset_options.py'
+            output = subprocess.check_output('python ' + folder + ' ' + env + ' ' + model['name'] + ' ' + str(model['id']),
+                                             shell=True, encoding='utf-8').strip()
+            l = output.split('\n')
+            m = l[-1]
+            l = ast.literal_eval(m)
+            selected = let_user_pick(l)
+            # print('selected', selected)
+            if not selected == None:
+                selected_dataset = l[selected]
+                # print('model',model)
+                # print('selected_dataset', selected_dataset)
+                folder = currentPipelineFolder + '/tester/dsp/add_experiment.py'
+                subprocess.call(('dvc_push.sh'), shell=True)
+                output = subprocess.call(('python', folder, env, json.dumps(model), json.dumps(selected_dataset), tag), shell=True)
+                print('you can see your experiment in que')
+            else:
+                print('selection does not exist')
+        except Exception as e:
+            print(m)
+    else:
+        print('could not get models')
+
 
 @cli.command()
 def create_deploy_files():
@@ -187,12 +235,14 @@ def create_folders(project_name):
     create_main_folders('schema', 'pipeline')
     create_main_folders('tester', 'main')
     create_main_folders('test_schema', 'tester')
+    create_main_folders('dsp', 'tester')
     create_main_folders('trainer', 'main')
     create_main_folders('server', 'main')
 
 
 def create_project(project_name):
     create_folders(project_name)
+    original_project_name = project_name
     project_name = clean_name(project_name)
 
     # Create pipeline files
@@ -216,6 +266,10 @@ def create_project(project_name):
     create_schema_file(project_name, directories['test_schema'], 'test_input', False)
     create_schema_file(project_name, directories['test_schema'], 'test_output', False)
 
+    create_dsp_file(original_project_name, directories['dsp'], 'get_model_options', False)
+    create_dsp_file(original_project_name, directories['dsp'], 'get_dataset_options', False)
+    create_dsp_file(original_project_name, directories['dsp'], 'add_experiment', False)
+
     # Create server files
     create_server_file(project_name, directories['server'], 'main', False)
     create_server_file(project_name, directories['server'], 'test_server_post', False)
@@ -260,6 +314,10 @@ def create_tester_file(project_name, folder, test_file_type, createInitFile=True
     data = read_template_file('tester/' + test_file_type)
     replace_in_template_and_create_file(project_name, folder, test_file_type, data, createInitFile)
 
+def create_dsp_file(project_name, folder, test_file_type, createInitFile=True):
+    data = read_template_file('tester/dsp/' + test_file_type)
+    replace_in_template_and_create_file(project_name, folder, test_file_type, data, createInitFile)
+
 
 def create_exist_pipeline_file(type, fileName):
     pipelineType = type + 's'
@@ -655,6 +713,18 @@ def clean_existing_project_name(text):
     no_underscore_text = to_capitalize_no_underscore(text)
     return ''.join(elem.capitalize() for elem in no_underscore_text.split('-'))
 
+def let_user_pick(options):
+    print("Please choose:")
+    for idx, element in enumerate(options):
+        print("{}) {}".format(idx+1,element))
+    i = input("Enter number: ")
+    try:
+        if 0 < int(i) <= len(options):
+            return int(i)-1
+    except:
+        pass
+    return None
+
 
 if __name__ == '__main__':
     cli(prog_name='cli')
